# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-03-25 07:41
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone
import fernet_fields.fields
import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [
        ('edxval', '0015_remove_thirdpartytranscriptcredentialsstate_exists'),
    ]

    operations = [
        migrations.CreateModel(
            name='TranscriptCredentials',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('org', models.CharField(help_text='This value must match the value of organization in studio/edx-platform.', max_length=50, verbose_name='Organization')),
                ('provider', models.CharField(choices=[('Custom', 'Custom'), ('3PlayMedia', '3PlayMedia'), ('Cielo24', 'Cielo24')], max_length=50, verbose_name='Transcript provider')),
                ('api_key', fernet_fields.fields.EncryptedTextField(max_length=255, verbose_name='API key')),
                ('api_secret', fernet_fields.fields.EncryptedTextField(max_length=255, verbose_name='API secret')),
            ],
            options={
                'verbose_name_plural': 'Transcript Credentials',
            },
        ),
        migrations.AlterUniqueTogether(
            name='transcriptcredentials',
            unique_together=set([('org', 'provider')]),
        ),
    ]
